pygeodesy.units.Lat

Package pygeodesy :: Module units :: Class Lat |
[frames] | no frames]

# Class Lat

              object --+
                       |
                   float --+
                           |
          object --+       |
                   |       |
        named._Named --+   |
                       |   |
    unitsBase._NamedUnit --+
                           |
             unitsBase.Float --+
                               |
                         Degrees --+
                                   |
                                  Lat

Known Subclasses:
  - karney._Lat
  - , rhumb.bases._Lat

Named `float` representing a latitude in `degrees`.

Instance Methods
Inherited from `Degrees`: `toDegrees`, `toRadians`, `toRepr`, `toStr` Inherited from `unitsBase.Float`: `__repr__`, `__str__` Inherited from `float`: `__abs__`, `__add__`, `__coerce__`, `__div__`, `__divmod__`, `__eq__`, `__float__`, `__floordiv__`, `__format__`, `__ge__`, `__getattribute__`, `__getformat__`, `__getnewargs__`, `__gt__`, `__hash__`, `__int__`, `__le__`, `__long__`, `__lt__`, `__mod__`, `__mul__`, `__ne__`, `__neg__`, `__nonzero__`, `__pos__`, `__pow__`, `__radd__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rmod__`, `__rmul__`, `__rpow__`, `__rsub__`, `__rtruediv__`, `__setformat__`, `__sub__`, `__truediv__`, `__trunc__`, `as_integer_ratio`, `conjugate`, `fromhex`, `hex`, `is_integer` Inherited from `named._Named`: `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, arg=None, name=`'``lat``'`, clip=90, **Error_name_arg) New, named Lat, see Degrees. |

Properties
Inherited from `unitsBase.Float`: `isneg0` Inherited from `float`: `imag`, `real` Inherited from `unitsBase._NamedUnit`: `std_repr`, `units` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (cls, arg=None, name=`'``lat``'`, clip=90, **Error_name_arg) Static Method |
New, named Lat, see Degrees. Arguments: `cls` - This class (`Degrees` or sub-class). `arg` - The value (any `type` convertable to `float` or parsable by function parseDMS). `name` - Optional instance name (`str`). `suffix` - Optional, valid compass direction suffixes (`NSEW`). `clip` - Optional `arg` range `-clip..+clip` (`degrees` or `0` or `None` for unclipped). `wrap` - Optionally adjust the `arg` value (wrap90, wrap180 or wrap360). `Error` - Optional error to raise, overriding the default UnitError. `name_arg` - Optional `name=arg` keyword argument, inlieu of separate `arg` and `name` ones. Returns: a new object with type S, a subtype of T A `Degrees` instance. Raises: `Error` - Invalid `arg` or `abs(arg)` outside the `clip` range and rangerrors is `True`. Overrides: object.__new__